@@ -5,4 +5,4 @@ from napari_allencell_annotator.controller.main_controller import MainController
 @napari_hook_implementation
 def napari_experimental_provide_dock_widget():
     # you can return either a single widget, or a sequence of widgets
-    return [(MainController, {"name": "Annotatorty"})]
+    return [(MainController, {"name": "Annotator"})]
