@@ -1,4 +1,5 @@
-from typing import Dict
+from typing import Dict, Optional, Any
+
 from napari_allencell_annotator._style import Style
 from qtpy import QtWidgets
 from qtpy.QtCore import Qt
@@ -24,25 +25,31 @@ class CreateDialog(QDialog):
     -------
     get_annots()
         Sets annotation dictionary and emits valid_annots_made signal if all annotations are valid.
+    render_annotations()
+        Displays the types and defaults for each existing annotation.
     """
 
     # signal emitted when all annotations created are valid
     valid_annots_made = Signal()
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, existing_annots: Optional[Dict[str, Dict[str, Any]]] = None):
         super().__init__(parent)
-
         self.setStyleSheet(Style.get_stylesheet("main.qss"))
 
         self.setWindowTitle("Create Annotations")
         self.setMinimumSize(700, 500)
 
         self.list = AnnotationWidget()
-        self.list.add_new_item()
 
-        label = QLabel("Create Annotations")
-        label.setAlignment(Qt.AlignCenter)
         self.layout = QVBoxLayout()
+        self.existing_annots = existing_annots
+        if self.existing_annots is None:
+            self.list.add_new_item()
+            label = QLabel("Create Annotations")
+            label.setAlignment(Qt.AlignCenter)
+        else:
+            label = QLabel("Edit Annotations")
+        label.setAlignment(Qt.AlignCenter)
         self.layout.addWidget(label)
 
         self.scroll = QScrollArea()
@@ -52,7 +59,8 @@ class CreateDialog(QDialog):
 
         self.add = QPushButton("Add +")
         self.delete = QPushButton("Delete Selected")
-        self.cancel = QPushButton("Cancel")
+        self.delete.setToolTip("Click boxes on the left of items to select for deletion")
+        self.cancel = QPushButton("Cancel")  # check: if edit -> cancel go back to view
         self.apply = QPushButton("Apply")
         self.btns = QWidget()
         self.new_annot_dict: Dict[str, Dict] = None
@@ -62,7 +70,7 @@ class CreateDialog(QDialog):
         sp_retain = QtWidgets.QSizePolicy()
         sp_retain.setRetainSizeWhenHidden(True)
         self.delete.setSizePolicy(sp_retain)
-        self.delete.hide()
+        self.delete.setEnabled(False)
         layout.addWidget(self.cancel)
         layout.addWidget(self.apply)
 
@@ -73,6 +81,13 @@ class CreateDialog(QDialog):
         self.layout.addWidget(self.btns)
 
         self.setLayout(self.layout)
+
+        if self.existing_annots:
+            self.render_annotations()
+        self._connect_slots()
+
+    def _connect_slots(self):
+        """Connect signals and slots"""
         self.add.clicked.connect(self._add_clicked)
         self.cancel.clicked.connect(self.reject)
         self.apply.clicked.connect(self.get_annots)
@@ -89,18 +104,22 @@ class CreateDialog(QDialog):
         checked : bool
             True if delete is currently hidden.
         """
-        if checked:
-            self.delete.show()
-        else:
-            self.delete.hide()
+        self.delete.setEnabled(checked)
+
+    def render_annotations(self):
+        """Display the types and defaults for each existing annotation."""
+        for name, dct in self.existing_annots.items():
+            self.list.add_existing_item(name, dct)
 
     def _delete_clicked(self):
-        """Delete checked items if there is at least one item checked"""
+        """Delete checked items if there is at least one item checked."""
         if self.list.num_checked > 0:
             self.list.delete_checked()
+        if self.list.count() <= 9:
+            self.add.show()
 
     def _add_clicked(self):
-        """Add a new item if there are less than 9. Hide add button otherwise"""
+        """Add a new item if there are less than 9. Hide add button otherwise."""
         self.list.add_new_item()
         if self.list.count() > 9:
             self.add.hide()
